// rf95_client.pde
// -*- mode: C++ -*-
// Example sketch showing how to create a simple messageing client
// with the RH_RF95 class. RH_RF95 class does not provide for addressing or
// reliability, so you should only use RH_RF95 if you do not need the higher
// level messaging abilities.
// It is designed to work with the other example rf95_server
// Tested with Anarduino MiniWirelessLoRa, Rocket Scream Mini Ultra Pro with
// the RFM95W, Adafruit Feather M0 with RFM95

#include <RH_RF95.h>
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>
#include "dtostrf.h"

// Singleton instance of the radio driver
RH_RF95 rf95(8, 3); // Adafruit Feather M0 with RFM95 

#define BME_SCK 13
#define BME_MISO 12
#define BME_MOSI 11
#define BME_CS 10

Adafruit_BME280 bme; // I2C

String datastring="";
char databuf[10];
uint8_t dataoutgoing[10];

void setup() 
{
  Serial.begin(9600);
  Serial.println(F("BME280 test"));

  bool status;
    
  // default settings
  // (you can also pass in a Wire library object like &Wire2)
  if (!bme.begin()) {
      Serial.println("Could not find a valid BME280 sensor, check wiring!");
      while (1);
  }

  if (!rf95.init())
    Serial.println("rf95 init failed");
}

void loop()
{
  // Read and print out the temperature, then convert to *F
  float c = bme.readTemperature();
  float f = c * 9.0 / 5.0 + 32;
  Serial.print("Temp: "); Serial.print(c); Serial.print("*C\t"); 
  Serial.print(f); Serial.println("*F");

  float h = bme.readHumidity();
  Serial.print("Humidity: ");
  Serial.print(h); Serial.println(" %");
    
  Serial.println("Sending to rf95_server");
  
  // Send a message to rf95_server
  uint8_t entry[] = "Temperature Sent";
  rf95.send(entry, sizeof(entry));

  datastring += dtostrf(f, 4, 2, databuf);
  strcpy((char *)dataoutgoing,databuf);
  Serial.println(databuf);
  rf95.send(dataoutgoing, sizeof(dataoutgoing));
  rf95.waitPacketSent();
  delay(400);

  uint8_t entry2[] = "Humidity Sent";
  rf95.send(entry2, sizeof(entry2));

  datastring += dtostrf(h, 4, 2, databuf);
  strcpy((char *)dataoutgoing,databuf);
  Serial.println(databuf);
  rf95.send(dataoutgoing, sizeof(dataoutgoing));
  rf95.waitPacketSent();
  delay(400);
  
  rf95.sleep();
  
  delay(10000);
}
